---
name: Content/Voice and tone
slug: voice-and-tone
icon: IconVoiceAndTone
keywords:
  - sound like Shopify
  - personality of Shopify
  - brand personality
  - empathy
  - merchant feelings
  - merchant emotions
  - merchant context
  - content voice
  - content tone
---

# Voice and tone

Learn how to apply Shopify’s voice and choose the right tone, no matter what
product, feature, or app you’re building.

---

## What are voice and tone?

<!-- keywords: difference between voice and tone, what is voice, what is tone, what does voice mean?, what does tone mean? -->

Shopify’s voice is a reflection of who we are. We should always sound like
Shopify.

At the same time, some aspects of our personality might be more or less apparent, depending on the audience and their context. That’s tone.

---

## Shopify’s voice

Our voice is a reflection of who we are. So who are we?

**Simply put, we’re a company, built by real people who understand this business and care about helping others succeed.**

**That should be clear every time someone uses our products or services.**

Most often, we show this through well-crafted tools that help people get their jobs done efficiently. But there are times when our personalities and perspectives should be more apparent. In those times, we should adapt our tone to respond to people in an appropriate and meaningful way.

You'll find more specific guidelines on how to adapt your tone to different situations in this guide.

---

## Voice guidelines

<!-- keywords: confident not arrogant, empathetic not overprotective, transparent not blunt, what is shopifys voice, what is shopify’s voice, what does shopify sound like, sound like, shopifys personality, shopify’s personality, voice writing, confident, empathetic, transparent, not arrogant, not overprotective, not blunt, arrogant, overprotective, blunt -->

As Shopify’s voice, we should always:

<div class="twoColumnsResponsive twoColumnsResponsiveLoose">
<div markdown="1" class="twoColumnsItem">

![](/public_images/content/voice-and-tone/CustomersMajor.svg)

### Be real, but not too tough or overly familiar

- Use business casual language—be plain-spoken, not pretentious or overly playful
- Be upfront and honest with merchants, even if we make a mistake
- Communicate with clarity and empathy—be direct, not insensitive

</div>
<div markdown="1" class="twoColumnsItem">

![](/public_images/content/voice-and-tone/HintMajor.svg)

### Be proactive, but not needy or pushy

- Offer merchants sincere encouragement and practical advice
- Clearly explain how merchants are impacted when something goes wrong, but don’t overexplain with redundant content

</div>
</div>

<div class="twoColumnsResponsive twoColumnsResponsiveLoose">
<div markdown="1" class="twoColumnsItem">

![](/public_images/content/voice-and-tone/WandMajor.svg)

### Be dynamic, but not scattered or impulsive

- Communicate in a way that respects merchant emotion and context
- Avoid words that generalize success like “every,” “all,” and “most”
- Use language that supports action, movement, and progress

</div>
<div markdown="1" class="twoColumnsItem">

![](/public_images/content/voice-and-tone/NavigationMajor.svg)

### Guide, but don’t handhold or prescribe

- Use expertise to help merchants succeed; don’t talk down to them
- Be specific when explaining benefits without making things sound better than they are
- Teach people the “why” and “how” behind actions—don’t just tell them to do something

</div>
</div>

---

## Adapting tone by situation

<!-- keywords: tone examples, error message tone, tone of an error messages, positive tones, neutral tones, negative tones, change in tones, changing tones, tone of messages, message tones, tone guidelines -->

Our tone adapts to the context. We’ll use certain voice attributes more or less based on the situation.

Often people frame tone guidance around adapting to the emotional state of the audience. The reality is we never know a person’s emotional state. Even when things seem the most positive, we can’t be sure.

While it’s helpful to consider how your audience is likely to feel, don’t assume or tell them how to feel. Instead, focus on the specifics of the situation and less on the emotions. Here are some of the most common situations to consider.

### Everyday tasks and activities

When everything is working as it should, our goal is to give people what they need to get work done, without getting in the way or drawing attention to ourselves. We want the audience to know what something is or that something has happened as expected.

<!-- usageblock -->

#### Do

Look for the simplest way to communicate information—words aren’t always necessary.

![Images showing icons of an eye representing a “view” action, a picture frame representing the concept of "images" and a spyglass representing the action of "search".](/public_images/content/voice-and-tone/view-icon@2x.png)

#### Don’t

Use overly complicated or intimidating language.

![Image showing a toggle switch on a card labeled “Use Biometrics for Authentication”](/public_images/content/voice-and-tone/biometrics-toggle-card@2x.png)

<!-- end -->

<!-- usageblock -->

#### Do

Be consistent for identical actions or destinations when possible.

- _Delete product_
- _Delete collection_

#### Don’t

Add extra text just to fill space.

![Image showing a text field for notes labeled “Add a note” followed by an ellipsis](/public_images/content/voice-and-tone/add-note-field@2x.png)

<!-- end -->

### Learning and education

Sometimes it helps to give more explanation or education. In these situations, we want to make sure people feel confident in their actions and in our capabilities.

Some people will want to be guided step-by-step through the process, while others may just want to try it out and learn on their own. Look for ways to give them both options.

Remember, they may have sought this out specifically or we may have recommended it to them, so don’t assume that they want or need to use it.

<!-- usageblock -->

#### Do

Help people understand why they should do something, not just how.

![A home card suggesting to add a shipping policy to your store to build trust with customers](/public_images/content/voice-and-tone/shipping-policy-card@2x.png)

#### Don’t

Oversell or overpromise.

_Create a new campaign and you could double your sales this holiday season._

<!-- end -->

<!-- usageblock -->

#### Do

Break down complicated tasks into steps that help people focus on one thing at a time.

![A home card with separate tabs for adding a product, customizing a theme, and adding a domain](/public_images/content/voice-and-tone/onboarding-tasks@2x.png)

#### Don’t

Be overly prescriptive about how someone should use a feature.

_You need to add at least 10 products before opening your store._

<!-- end -->

### Simple errors

While we do our best to be proactive and protect against unexpected events, they still happen. These are often simple mistakes or roadblocks to action that can easily be fixed. Although they aren’t necessarily errors or problems, they can feel that way at first.

In this case, our job is to help people understand what happened so that they can get back to work as quickly as possible

Read the [error message guidelines](https://polaris.shopify.com/patterns/error-messages) for more detailed guidance.

<!-- usageblock -->

#### Do

Clearly explain the situation and how it can be resolved.

_Product weight needs to be positive. Change the product weight to be greater than or equal to 0 and try again._

#### Don’t

Use overly dramatic or scary words for simple errors.

_Bad request, forbidden, fatal, expectation failed, unresolved, invalid_

<!-- end -->

<!-- usageblock -->

#### Do

Look for ways to help people resolve problems automatically.

![An email input form element with a typo in the inputted email address and a hint text underneath it guiding the user to fix the typo.](/public_images/content/voice-and-tone/email-error-message@2x.png)

#### Don’t

Use error numbers or code unless they’re easily recognizable by people and help them solve the problem.

![Error modal with a confusing error code stating “200 OK”](/public_images/content/voice-and-tone/channel-not-found-error@2x.png)

<!-- end -->

### Acknowledging effort, progress, or completion

There are situations where we want to acknowledge that someone completed a complex activity or difficult task.

While we don’t need to celebrate the accomplishment, we should recognize that they put in the time and effort. Depending on the level of effort, these may be simple confirmations or more active recognition that they completed something difficult.

<!-- usageblock -->

#### Do

If this is a task people do regularly, make it clear that the step is complete in a simple and non-intrusive way, like a [toast](/components/feedback-indicators/toast). Consider ways to confirm completion without words or messaging.

_Product saved_

#### Don’t

Assume people are excited or celebrating. They may be annoyed if it was a particularly long process or if the immediate benefits aren’t clear.

_Congrats! You set up your single login for Shopify._

<!-- end -->

<!-- usageblock -->

#### Do

If the task was something we initiated or required, thank them for their time.

_Thanks for taking the time to share your feedback._

#### Don’t

Refer to simple actions or completed steps as “successes.”

_You successfully added a product._

<!-- end -->

### Motivate or encourage action

These are situations when we want to keep people moving along a desired path. In most cases, we do that with direct information and clear steps to encourage action.

We don’t want to be too overzealous or action-driven here—it’s more about helping people understand the next step and giving them the context they need to take it.

<!-- usageblock -->

#### Do

Help people understand what the next steps are and why they should take them.

_Your email address is connected to 8 accounts. Set up a single login to switch between stores faster and log in less often._

#### Don’t

Assume the next step or outcome is guaranteed.

_You’re just a few steps away from receiving your first order._

<!-- end -->

<!-- usageblock -->

#### Do

Provide guidance to help people understand if the decision is right for them.

_Based on your type of business, this is the POS hardware we recommend:._

<!-- end -->

### Serious problems or errors

There are times when we need to share bad news. This might be an outage or an error, or it may be a product that we’re no longer supporting. These are hopefully rare situations, but they will happen.

In this case, there’s a serious risk of damaging trust and hurting our relationship with the audience, so we should be very careful about how we communicate.

Read the [error message guidelines](https://polaris.shopify.com/patterns/error-messages) for more detailed guidance.

<!-- usageblock -->

#### Do

Explain the impact on their business clearly, without using confusing or scary language.

_Some of today’s sales data hasn’t been updated yet. This will be fixed shortly. Your data is safe, and your sales are not affected._

#### Don’t

Ask merchants to trust us without providing data or context.

_Today’s sales data might not be accurate, but don’t worry—it’s just temporary._

<!-- end -->

<!-- usageblock -->

#### Do

Apologize and empathize when we’re at fault, but within reason.

_All systems are now fully operational. We recognize and apologize for the stress, concern, and impact this outage had on your business. In the coming days we will be working to fully understand how this widespread internet infrastructure failure affected our platform._

<!-- end -->

<!-- usageblock -->

#### Do

Provide clear steps to resolve issues. If there’s no solution, be direct about what that means for the merchant and what we’re doing about it.

_Your Shopify Payments account is on hold. Please attach your State Tax Exemption Certificate for review._

<!-- end -->

<a name="announcing-features"></a>

### Announcing new features and updates

It’s exciting to launch a new feature or update, but always consider the audience’s perspective first. While we may be excited about the benefits and capabilities, change can be intimidating or annoying for users.

When you’re announcing something new, focus on educating and explaining what it is, what it’s used for, and what the user can expect.

<!-- usageblock -->

#### Do

Pitch our product by explaining the specific merchant benefits.

_**Introducing the new Buy Button** <br />
Make it your own with custom fonts, colors, and styles. It also loads 50% faster so your visitors won’t miss it._

#### Don’t

Just talk about ourselves and assume the experience for merchants will be easy.

_**Get Shopify’s new Buy Button** <br />
It’s never been easier to customize the fonts, colors, and styles of Buy Buttons. It’s also twice as fast._

<!-- end -->

<!-- usageblock -->

#### Do

If possible, let users dismiss announcements or postpone changes until they’re ready.

![A modal with a secondary button option to “remind me later” for a “single login” feature.](/public_images/content/voice-and-tone/remind-later-button@2x.png)

<!-- end -->

### Celebrations and congratulations

There are occasionally times when we want to celebrate an event or milestone, or to congratulate someone for an important accomplishment. In reality, this should be one of the least common situations we encounter.

Let audiences know that we understand that it’s an important moment and we’re excited for them, but be careful not to take credit for it. Even if we played a role in their success, this isn’t about us.

Remember, this is about celebrating their accomplishments, not ours. Launching something new? You probably don’t need to celebrate with them. Read our guidance around [announcing new features and updates](#announcing-features).

<!-- usageblock -->

#### Do

Only celebrate truly important or monumental situations when the audience likely feels proud, excited, or satisfied.

_Your store is 1 year old today! Here’s to many more._

#### Don’t

Celebrate completing tasks or processes that people don’t actually want to celebrate. Did they finish something difficult or do something for us? You may want to acknowledge their effort instead.

_You set up your payment providers, congrats!_

<!-- end -->

<!-- usageblock -->

#### Do

Express genuine happiness for merchants. Recognize their accomplishment and congratulate them on a job well done.

_You launched your store! Nice work._

#### Don’t

Take credit for merchants’ successes or presume to know what they need.

_We did it! Congrats on your first sale._

<!-- end -->
